@@ -49,6 +49,11 @@ setMethod("$",
           "MVIVW",
           function(x, name) slot(x, name))
 
+#' @rdname getter
+setMethod("$",
+          "MVEgger",
+          function(x, name) slot(x, name))
+
 #' @rdname getter
 setMethod("$",
           "MRMVInput",
@@ -57,4 +62,9 @@ setMethod("$",
 #' @rdname getter
 setMethod("$",
           "MRHetPen",
-          function(x, name) slot(x, name))
\ No newline at end of file
+          function(x, name) slot(x, name))
+
+#' @rdname getter
+setMethod("$",
+          "MRConMix",
+          function(x, name) slot(x, name))
